use std::{
    fs::{self},
    path::PathBuf,
    time::Instant,
};

use binrw::{BinRead, BinWriterExt};
use clap::Parser;
use clap_verbosity_flag::{InfoLevel, Verbosity};
use ezcad::file::Header;
use log::{debug, info};

#[derive(Debug, Parser)]
struct Cli {
    /// Input file to parse
    #[arg(short, long)]
    input: PathBuf,

    /// Output file to write to
    #[arg(short, long)]
    output: Option<PathBuf>,

    // /// Configuration file
    // #[arg(short, long)]
    // config: PathBuf,
    #[command(flatten)]
    verbose: Verbosity<InfoLevel>,
}

fn main() {
    let cli: Cli = Cli::parse();

    env_logger::builder()
        .format_timestamp(None)
        .filter_level(cli.verbose.log_level_filter())
        .init();

    let mut input = fs::File::open(cli.input).unwrap();
    // let _config = read(args.config).unwrap();

    let time = Instant::now();
    let file = Header::read_le(&mut input).unwrap();
    info!("Decode time: {:?}", time.elapsed());

    for pen in file.pens_offset.data.pens.iter().take(1) {
        debug!("{:#?}", pen);
    }

    for layer in file.layers_offset.iter() {
        for object in layer.objects.iter() {
            debug!("{:#?}", object);
        }
    }

    if let Some(output) = cli.output {
        let mut output = fs::File::create(output).unwrap();
        let time = Instant::now();
        output.write_le(&file).unwrap();
        info!("Encode time: {:?}", time.elapsed());
    }
}
